@@ -14,12 +14,30 @@ class ShouldIndex:
             # 上下padding 留了多少
             'top_padding_ratio': 0,
             'bottom_padding_ratio': 0,
+            # 上下裁剪点是否存在
+            'top_point': False,
+            'bottom_point': False,
         }
 
     def expected_crop_result(self):
         if self.crop_indexing_dict['get_crop_point']['status']:
             self.crop_indexing_dict['expected_crop_result'] = True
 
+    def top_and_bottom_crop_result(self, flag=False):
+        """
+        :param flag: flag为True,设置的上下裁剪点都可以满足
+                     flag为False,设置的上下裁剪点只可以满足上
+        :return:
+        """
+
+        # 裁剪后 上下裁剪点 是否存在
+        if self.crop_indexing_dict['get_crop_point']['top_status']:
+            self.crop_indexing_dict['top_point'] = True
+
+        if self.crop_indexing_dict['get_crop_point']['bottom_status'] and flag:
+            self.crop_indexing_dict['bottom_point'] = True
+
+
     def extension(self):
         self.crop_indexing_dict['extension'] = {
             'status': True
@@ -85,6 +103,8 @@ class ShouldIndex:
             'origin_crop_site': origin_crop_site,
             'crop_site': crop_site,
             'status': True if origin_crop_site == crop_site else False,
+            'top_status': True if origin_crop_site[0] == crop_site[0] else False,
+            'bottom_status': True if origin_crop_site[1] == crop_site[1] else False,
         }
 
     def get_top_and_bottom_padding(self, top, padding_top, bottom, padding_bottom):
@@ -213,6 +233,7 @@ class ImageCrop:
                 crop_width = slot_width / scale_x
                 crop_height = ((y2 - y1) * img.height)
                 amend_layout_height = (y2 - y1) * transform_img_height - slot_height
+
             else:
                 # 新逻辑
                 height_scale = slot_height / ((y2 - y1) * img.height)
@@ -244,7 +265,7 @@ class ImageCrop:
 
             crop_x = x * img.width
             crop_y = y * img.height
-
+            self.si.top_and_bottom_crop_result(True)  # 上下裁剪点都存在
         elif crop_method == 'e':  # 扩边裁剪，slot高不变,宽可以改变
             crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height = self.__extension_crop(
                 y1, y2, {'x1': x1, 'x2': x2}, [slot_width, slot_height], img
@@ -264,6 +285,7 @@ class ImageCrop:
 
                 self.si.main_part_offset(x * img.width + slot_width / scale_x / 2, x_center * img.width, 'x')
                 self.si.expected_crop_result()
+                self.si.top_and_bottom_crop_result(True)  # 上下裁剪点都存在
 
             else:
                 width_scale = slot_width / img.width
@@ -273,6 +295,7 @@ class ImageCrop:
                 if retain_x_or_y == "y":
                     scale_x = scale_y = width_scale
                     x = x1
+
                     y_center = y1 + (y2 - y1) / 2
                     self.si.main_part_offset(y1 * img.height + slot_height / scale_x / 2, y_center * img.height, 'y')
                 else:
@@ -292,6 +315,8 @@ class ImageCrop:
                     self.si.crop_head()
                     self.si.main_part_offset(0.5, 0.5, 'y')
 
+                self.si.top_and_bottom_crop_result(False)  # 上裁剪点都存在
+
             crop_x = x * img.width
             crop_y = y * img.height
             crop_width = slot_width / scale_x
@@ -565,14 +590,13 @@ class ImageCrop:
             human_box_bottom = img.crop_point['human_bottom']['bottom_site']
             human_x_flag = True
 
-
         if human_x_flag and cloth_x_flag:
             crop_left = min(human_box_top[0], human_box_bottom[0], cloth_box_top[0], cloth_box_bottom[0])
             crop_right = max(human_box_top[0], human_box_bottom[0], cloth_box_top[0], cloth_box_bottom[0])
         elif human_x_flag and not cloth_x_flag:
             crop_left = min(human_box_top[0], human_box_bottom[0])
             crop_right = max(human_box_top[0], human_box_bottom[0])
-        elif not human_x_flag and  cloth_x_flag:
+        elif not human_x_flag and cloth_x_flag:
             crop_left = min(cloth_box_top[0], cloth_box_bottom[0])
             crop_right = max(cloth_box_top[0], cloth_box_bottom[0])
         else:
